ApiHandler class

ApiService inClass Handler

Constructors

ApiHandler({required void apiStartCallback(), required void apiSuccessfulCallback(ApiSuccess apiData), required void apiFailedWithMsg(ApiError error), required void apiFailedCheckYourInternet(ApiError noInternetError)})

Properties

apiFailedCheckYourInternet → void Function(ApiError noInternetError)
final
apiFailedWithMsg → void Function(ApiError error)
final
apiStartCallback → void Function()
final
apiSuccessfulCallback → void Function(ApiSuccess apiData)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited