ClassApiHandler mixin

ApiService ClassHandler

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apiFailedCheckYourInternet(ApiError noInternetError) → void
apiFailedWithMsg(ApiError error) → void
apiStartCallback() → void
apiSuccessfulCallback(ApiSuccess apiData) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited