showDebugLog method
Set if you want to print debug log for response
Implementation
void showDebugLog(bool showDebugLog) {
_showDebugLog = showDebugLog;
}
Set if you want to print debug log for response
void showDebugLog(bool showDebugLog) {
_showDebugLog = showDebugLog;
}