ApiSuccess<T> class

ApiService ApiSuccess Model

Constructors

ApiSuccess()

Properties

data ↔ T?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String
getter/setter pair
result bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
getter/setter pair

Methods

apiSuccess(dynamic statusCode, dynamic message, dynamic data) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited