ApiService<R> class
Api Service RulTech Architecture https://gitlab.rultech.in/-/snippets/4
- Inheritance
-
- Object
- GetConnectInterface
- GetConnect
- GetConnectHelper
- ApiService
- Mixed-in types
Constructors
-
ApiService({bool showSnackBar = true, String baseUrl = "", List<
int> allowedStatusCodes = const [200]}) - ApiService Constructor
- ApiService.init(ApiHandler mHandler, {dynamic commonResponseModel, dynamic providerResponseModel, bool showSnackBar = true, String baseUrl = ""})
-
ApiService Factory Constructor
factory
- ApiService.initWithThis(ClassApiHandler mClassHandler, {dynamic commonResponseModel, dynamic providerResponseModel, bool showSnackBar = true, String baseUrl = ""})
-
ApiService Factory Constructor
factory
Properties
- allowAutoSignedCert ↔ bool
-
getter/setter pairinherited
- baseUrl ↔ String
-
finalgetter/setter pairinherited
- defaultContentType ↔ String
-
getter/setter pairinherited
- defaultDecoder ↔ Decoder?
-
getter/setter pairinherited
- defaultTimeoutSeconds → dynamic
-
no setter
- findProxy ↔ String Function(Uri url)?
-
getter/setter pairinherited
- followRedirects ↔ bool
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → dynamic
-
no setter
- httpClient → GetHttpClient
-
no setterinherited
- initialized → bool
-
Checks whether the controller has already been initialized.
no setterinherited
- isClosed → bool
-
Checks whether the controller has already been closed.
no setterinherited
- isDisposed → bool
-
no setterinherited
- maxAuthRetries ↔ int
-
getter/setter pairinherited
- maxRedirects ↔ int
-
getter/setter pairinherited
- mClassHandler → dynamic
-
no setter
- mHandler → dynamic
-
no setter
-
onDelete
→ InternalFinalCallback<
void> -
Internal callback that starts the cycle of this controller.
finalinherited
-
onStart
→ InternalFinalCallback<
void> -
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclases.
This method should be internal and is required to define the
lifetime cycle of the subclass.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendUserAgent ↔ bool
-
getter/setter pairinherited
- showSnackBar → dynamic
-
no setter
- snackBar → bool
-
Get SnackBar Preference
no setter
-
sockets
↔ List<
GetSocket> -
getter/setter pairinherited
- tag ↔ String
-
getter/setter pair
- timeout ↔ Duration
-
getter/setter pairinherited
-
trustedCertificates
↔ List<
TrustedCertificate> ? -
getter/setter pairinherited
- userAgent ↔ String
-
getter/setter pairinherited
- withCredentials ↔ bool
-
getter/setter pairinherited
Methods
-
$configureLifeCycle(
) → void -
inherited
-
apiFailedWithMsg(
ApiError error) → void -
Handle Api with failed message
override
-
apiOnProgress(
int update) → void -
Handle Api progress
override
-
apiStart(
) → void -
Handle Api Start
override
-
apiSuccessful(
ApiSuccess apiData) → void -
Handle Api Successful
override
-
delete<
T> (String url, {Map< String, String> ? headers, String? contentType, Map<String, dynamic> ? query, Decoder<T> ? decoder}) → Future<Response< T> > -
inherited
-
deleteRequest(
String endUrl, {Map< String, String> ? headers, String? contentType, Decoder? decoder, Map<String, dynamic> ? query}) → Future - API Delete Method
-
dispose(
) → void -
inherited
-
get<
T> (String url, {Map< String, String> ? headers, String? contentType, Map<String, dynamic> ? query, Decoder<T> ? decoder}) → Future<Response< T> > -
inherited
-
getNetworkError(
) → dynamic -
inherited
-
getRequest(
String endUrl, {Map< String, String> ? headers, String? contentType, Map<String, dynamic> ? query, Decoder? decoder}) → Future - API Get Method
-
makeRequest(
String endUrl, String method, {dynamic body, String? contentType, Decoder? decoder, Map< String, String> ? headers, Map<String, dynamic> ? query, Progress? uploadProgress}) → Future - API request Method
-
mutation<
T> (String mutation, {String? url, Map< String, dynamic> ? variables, Map<String, String> ? headers}) → Future<GraphQLResponse< T> > -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onClose(
) → void -
Called before
onDeletemethod.onClosemight be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.inherited -
onInit(
) → void -
GetConnect Init
override
-
onReady(
) → void -
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
patch<
T> (String url, dynamic body, {String? contentType, Map< String, String> ? headers, Map<String, dynamic> ? query, Decoder<T> ? decoder, Progress? uploadProgress}) → Future<Response< T> > -
inherited
-
patchRequest(
String endUrl, dynamic body, {String? contentType, Decoder? decoder, Map< String, String> ? headers, Map<String, dynamic> ? query, Progress? uploadProgress}) → Future - API Patch Method
-
post<
T> (String? url, dynamic body, {String? contentType, Map< String, String> ? headers, Map<String, dynamic> ? query, Decoder<T> ? decoder, Progress? uploadProgress}) → Future<Response< T> > -
inherited
-
postRequest(
String endUrl, dynamic body, {String? contentType, Decoder? decoder, Map< String, String> ? headers, Map<String, dynamic> ? query}) → Future - API Post Method
-
processAndHandleResponse(
Response response) → dynamic - ApiService Process and return response
-
put<
T> (String url, dynamic body, {String? contentType, Map< String, String> ? headers, Map<String, dynamic> ? query, Decoder<T> ? decoder, Progress? uploadProgress}) → Future<Response< T> > -
inherited
-
putRequest(
String endUrl, dynamic body, {String? contentType, Decoder? decoder, Map< String, String> ? headers, Map<String, dynamic> ? query, Progress? uploadProgress}) → Future - API Put Method
-
query<
T> (String query, {String? url, Map< String, dynamic> ? variables, Map<String, String> ? headers}) → Future<GraphQLResponse< T> > -
query allow made GraphQL raw queries
final connect = GetConnect();
connect.baseUrl = 'https://countries.trevorblades.com/';
final response = await connect.query(
r"""
{
country(code: "BR") {
name
native
currency
languages {
code
name
}
}
}
""",
);
print(response.body);
inherited
-
request<
T> (String url, String method, {dynamic body, String? contentType, Map< String, String> ? headers, Map<String, dynamic> ? query, Decoder<T> ? decoder, Progress? uploadProgress}) → Future<Response< T> > -
inherited
-
setApiBearerToken(
Map< String, String> ? headers) → void - Set Api Bearer Token
-
setApiMaxRetries(
GetHttpClient httpClient) → void - Set Max Retries
-
setApiTimeOut(
int defaultTimeout) → void - Set Api TimeOut
-
setAuthToken(
Map< String, String> ? headers) → void - Set Header or header token, can override the class
-
setBearerToken(
) → R - Set Header Bearer Token
-
setDefaultDecoder(
GetHttpClient httpClient) → void - Set Default Model Parser
-
setHeaders(
Map< String, String> ? headers) → R - Set Header Inline
-
setMaxAuthRetries(
int retryCount) → R - Set Connection Reties
-
setShowSnackBar(
bool value) → R -
setTimeOut(
int seconds) → R - Set Connection Timeout
-
showDebugLog(
bool showDebugLog) → void - Set if you want to print debug log for response
-
showSnackbar(
bool showSnackbar) → void - Set show SnackBar
-
socket(
String url, {Duration ping = const Duration(seconds: 5)}) → GetSocket -
inherited
-
throwErrorMakeRequest(
dynamic ex) → dynamic - Throw ApiError
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited